# Slot: uri


the URI to be used for the type in semantic web mappings

URI: [http://w3id.org/biolink/biolinkml/meta/type_uri](slot_uri)
## Domain and Range

[TypeDefinition](TypeDefinition.md) -><sub>opt</sub> [Uri](Uri.md)
## Inheritance

## Children

## Used by

 * [TypeDefinition](TypeDefinition.md)
